=== modified file 'tests.py'
--- tests.py	2006-03-22 04:40:36 +0000
+++ tests.py	2006-03-22 07:01:49 +0000
@@ -25,6 +25,16 @@
 +hello test world
  
 """
+    def _check_diff(self, diff=DIFF_1):
+        self.assertEqual(self.capture('diff', retcode=1),
+            self.DIFF_HEADER + diff + '\n')
+
+    def _check_shelf(self, idx, diff=DIFF_1):
+        shelf = open(os.path.join(self.tree.branch.base,
+                '.shelf/shelves/default/' + idx)).read()
+        shelf = shelf[shelf.index('\n') + 1:] # skip the message
+        self.assertEqual(shelf, diff)
+
     def test_shelf(self):
         self.__test_loop(1)
 
@@ -32,8 +42,8 @@
         self.__test_loop(10)
 
     def __test_loop(self, count):
-        tree = self.make_branch_and_tree('.')
-        self.__create_and_add_test_file(tree)
+        self.tree = self.make_branch_and_tree('.')
+        self.__create_and_add_test_file()
 
         while count > 0:
             count -= 1
@@ -41,9 +51,7 @@
             # Modify the test file
             file('test_file', 'w').write(self.MODIFIED)
 
-            # Check the diff is right
-            self.assertEqual(self.capture('diff', retcode=1),
-                self.DIFF_HEADER + self.DIFF_1 + '\n')
+            self._check_diff()
 
             # Shelve the changes
             self.run_bzr('shelve', '--all', retcode=0)
@@ -54,62 +62,51 @@
             # Make sure the file is actually back the way it was
             self.assertEqual(file('test_file').read(), self.ORIGINAL)
 
-            # Check the shelf is right
-            shelf = open(os.path.join(tree.branch.base,
-                        '.shelf/shelves/default/00')).read()
-            shelf = shelf[shelf.index('\n') + 1:] # skip the message
-            self.assertEqual(shelf, self.DIFF_1)
+            self._check_shelf('00')
 
             # Unshelve
             self.run_bzr('unshelve', '--all', retcode=0)
 
-            # Check the diff is right again
-            self.assertEqual(self.capture('diff', retcode=1),
-                self.DIFF_HEADER + self.DIFF_1 + '\n')
+            self._check_diff()
 
             # Check the shelved patch was backed up
-            shelf = open(os.path.join(tree.branch.base,
-                        '.shelf/shelves/default/00~')).read()
-            shelf = shelf[shelf.index('\n') + 1:] # skip the message
-            self.assertEqual(shelf, self.DIFF_1)
+            self._check_shelf('00~')
 
             # Make sure the file is back the way it should be
             self.assertEqual(file('test_file').read(), self.MODIFIED)
 
     def test_shelf_nothing_to_shelve(self):
         import os.path
-        tree = self.make_branch_and_tree('.')
-        self.__create_and_add_test_file(tree)
+        self.tree = self.make_branch_and_tree('.')
+        self.__create_and_add_test_file()
 
         # Shelve the changes
         self.run_bzr('shelve', '--all', retcode=3)
 
-        if os.path.exists(os.path.join(tree.branch.base,
+        if os.path.exists(os.path.join(self.tree.branch.base,
                 '.shelf/shelves/default/00')):
             self.fail("Shelf exists, but it shouldn't")
 
-    def __create_and_add_test_file(self, tree, filename='test_file'):
+    def __create_and_add_test_file(self, filename='test_file'):
         f = open(filename, 'w')
         f.write(self.ORIGINAL)
         f.close()
-        tree.add(tree.relpath(os.path.join(os.getcwd(), filename)))
-        tree.commit(message='add %s' % filename)
+        self.tree.add(self.tree.relpath(os.path.join(os.getcwd(), filename)))
+        self.tree.commit(message='add %s' % filename)
 
     def test_shelf_with_revision(self):
-        tree = self.make_branch_and_tree('.')
+        self.tree = self.make_branch_and_tree('.')
 
-        self.__create_and_add_test_file(tree)
+        self.__create_and_add_test_file()
 
         # Modify the test file and commit it
         self.build_tree_contents([('test_file', self.MODIFIED)])
-        tree.commit(message='update test_file')
+        self.tree.commit(message='update test_file')
 
         # Shelve the changes
         self.run_bzr('shelve', '--all', '-r', '1', retcode=0)
 
-        # Check the diff is right
-        self.assertEqual(self.capture('diff', retcode=1),
-            self.DIFF_HEADER + self.DIFF_2 + '\n')
+        self._check_diff(self.DIFF_2)
 
         # Make sure the file is the way it should be
         self.assertEqual(file('test_file').read(), self.ORIGINAL)
@@ -121,7 +118,7 @@
         self.assertEqual(file('test_file').read(), self.MODIFIED)
 
     def test_shelf_with_two_revisions(self):
-        tree = self.make_branch_and_tree('.')
+        self.tree = self.make_branch_and_tree('.')
 
         cmd = 'shelve --all -r 1..2'
         (stdout, stderr) = self.run_bzr_captured(cmd.split(), retcode=None)
@@ -130,9 +127,9 @@
             'bzr: ERROR: shelve only accepts a single revision parameter.')
 
     def test_shelf_show_basic(self):
-        tree = self.make_branch_and_tree('.')
-        self.__create_and_add_test_file(tree)
-        self.__test_show(tree, '00')
+        self.tree = self.make_branch_and_tree('.')
+        self.__create_and_add_test_file()
+        self.__test_show(self.tree, '00')
 
     def __test_show(self, tree, patch):
         # Modify the test file
@@ -145,7 +142,7 @@
         self.assertEqual(self.capture('diff', retcode=0), '')
 
         # Check the shelf is right
-        shelf = open(os.path.join(tree.branch.base,
+        shelf = open(os.path.join(self.tree.branch.base,
                     '.shelf/shelves/default', patch)).read()
         self.assertTrue('patch %s' % patch in shelf)
 
@@ -154,14 +151,14 @@
         self.assertEqual(shown, shelf)
 
     def test_shelf_show_multi(self):
-        tree = self.make_branch_and_tree('.')
-        self.__create_and_add_test_file(tree)
-        self.__test_show(tree, '00')
-        self.__test_show(tree, '01')
-        self.__test_show(tree, '02')
+        self.tree = self.make_branch_and_tree('.')
+        self.__create_and_add_test_file()
+        self.__test_show(self.tree, '00')
+        self.__test_show(self.tree, '01')
+        self.__test_show(self.tree, '02')
 
         # Now check we can show a previously shelved patch
-        shelf = open(os.path.join(tree.branch.base,
+        shelf = open(os.path.join(self.tree.branch.base,
                     '.shelf/shelves/default/00')).read()
         self.assertTrue('patch 00' in shelf)
 
@@ -170,14 +167,14 @@
         self.assertEqual(shown, shelf)
 
     def test_shelf_show_with_no_patch(self):
-        tree = self.make_branch_and_tree('.')
+        self.tree = self.make_branch_and_tree('.')
         stderr = self.run_bzr_captured(['shelf', 'show', '00'], retcode=None)[1]
         self.assertTrue("Patch '00' doesn't exist on shelf default!" in stderr)
 
     def test_shelf_unshelve_failure(self):
-        tree = self.make_branch_and_tree('.')
+        self.tree = self.make_branch_and_tree('.')
 
-        self.__create_and_add_test_file(tree)
+        self.__create_and_add_test_file()
 
         # Modify the test file
         file('test_file', 'w').write(self.MODIFIED)
@@ -186,7 +183,7 @@
         self.run_bzr('shelve', '--all', retcode=0)
 
         # Write an unapplyable patch into the shelf
-        shelf = open(os.path.join(tree.branch.base,
+        shelf = open(os.path.join(self.tree.branch.base,
                     '.shelf/shelves/default/00'), 'w')
         shelf.write(self.DIFF_2)
         shelf.close()
@@ -195,7 +192,7 @@
         self.run_bzr('unshelve', '--all', retcode=3)
 
         # Make sure the patch is still there, eventhough it's broken
-        shelf = open(os.path.join(tree.branch.base,
+        shelf = open(os.path.join(self.tree.branch.base,
                     '.shelf/shelves/default/00')).read()
         self.assertEqual(shelf, self.DIFF_2)
 
@@ -204,10 +201,10 @@
         self.assertEqual(diff, '')
 
     def test_shelf_unshelve_failure_two_hunks(self):
-        tree = self.make_branch_and_tree('.')
+        self.tree = self.make_branch_and_tree('.')
 
-        self.__create_and_add_test_file(tree)
-        self.__create_and_add_test_file(tree, filename='test_file2')
+        self.__create_and_add_test_file()
+        self.__create_and_add_test_file(filename='test_file2')
 
         # Modify the test files
         file('test_file', 'w').write(self.MODIFIED)
@@ -218,7 +215,7 @@
 
         # Put the changes to test_file back, the shelved patch won't apply now
         file('test_file', 'w').write(self.MODIFIED)
-        tree.commit(message='screw up test_file')
+        self.tree.commit(message='screw up test_file')
 
         # Unshelve, should fail
         self.run_bzr('unshelve', '--all', retcode=3)
@@ -233,10 +230,10 @@
         self.assertTrue(os.path.exists('.shelf/shelves/default/00'))
 
     def test_shelf_after_unshelve(self):
-        tree = self.make_branch_and_tree('.')
+        self.tree = self.make_branch_and_tree('.')
 
-        self.__create_and_add_test_file(tree)
-        self.__create_and_add_test_file(tree, filename='test_file2')
+        self.__create_and_add_test_file()
+        self.__create_and_add_test_file(filename='test_file2')
 
         # Modify the test files
         file('test_file', 'w').write(self.MODIFIED)
@@ -262,10 +259,10 @@
         self.run_bzr('unshelve', '--all', retcode=0)
 
     def test_shelf_delete(self):
-        tree = self.make_branch_and_tree('.')
+        self.tree = self.make_branch_and_tree('.')
 
-        self.__create_and_add_test_file(tree)
-        self.__create_and_add_test_file(tree, filename='test_file2')
+        self.__create_and_add_test_file()
+        self.__create_and_add_test_file(filename='test_file2')
 
         # Modify the test files
         file('test_file', 'w').write(self.MODIFIED)
@@ -275,11 +272,7 @@
         self.run_bzr('shelve', '--all', 'test_file', retcode=0)
         self.run_bzr('shelve', '--all', 'test_file2', retcode=0)
 
-        # Check the shelf is right
-        shelf = open(os.path.join(tree.branch.base,
-                    '.shelf/shelves/default/00')).read()
-        shelf = shelf[shelf.index('\n') + 1:] # skip the message
-        self.assertEqual(shelf, self.DIFF_1)
+        self._check_shelf('00')
 
         # Delete 00
         self.run_bzr('shelf', 'delete', '00', retcode=0)
@@ -290,10 +283,7 @@
         self.assertTrue(os.path.exists('.shelf/shelves/default/01'))
 
         # Check the backup is right
-        shelf = open(os.path.join(tree.branch.base,
-                    '.shelf/shelves/default/00~')).read()
-        shelf = shelf[shelf.index('\n') + 1:] # skip the message
-        self.assertEqual(shelf, self.DIFF_1)
+        self._check_shelf('00~')
 
         # Check ls works
         list = self.capture('shelf ls', retcode=0).split('\n')
@@ -305,8 +295,8 @@
         self.assertEqual(file('test_file2').read(), self.MODIFIED)
 
     def test_shelf_gaps(self):
-        tree = self.make_branch_and_tree('.')
-        self.__create_and_add_test_file(tree)
+        self.tree = self.make_branch_and_tree('.')
+        self.__create_and_add_test_file()
         file('test_file', 'w').write(self.MODIFIED)
         self.run_bzr('shelve', '--all', 'test_file', retcode=0)
         file('test_file', 'w').write(self.MODIFIED)
@@ -322,9 +312,9 @@
         self.assertTrue(os.path.exists('.shelf/shelves/default/02'))
 
     def test_shelf_upgrade(self):
-        tree = self.make_branch_and_tree('.')
+        self.tree = self.make_branch_and_tree('.')
 
-        self.__create_and_add_test_file(tree)
+        self.__create_and_add_test_file()
 
         # Modify then shelve, so we're not upgrading to 00, just for kicks
         file('test_file', 'w').write(self.MODIFIED)
@@ -363,9 +353,9 @@
         self.run_bzr('shelve', '--all', retcode=0)
 
     def test_shelf_p0_patch(self):
-        tree = self.make_branch_and_tree('.')
+        self.tree = self.make_branch_and_tree('.')
 
-        self.__create_and_add_test_file(tree)
+        self.__create_and_add_test_file()
 
         # Run a benign shelf command to setup .shelf for us
         self.run_bzr('shelf', 'ls', retcode=0)
@@ -379,14 +369,11 @@
         # This should work
         self.run_bzr('unshelve', '--all', retcode=0)
 
-        # Check the diff is right
-        self.assertEqual(self.capture('diff', retcode=1),
-            self.DIFF_HEADER + self.DIFF_1 + '\n')
+        self._check_diff()
 
     def test_shelf_shelve_in_subdir(self):
-        tree = self.make_branch_and_tree('.')
-
-        self.__create_and_add_test_file(tree)
+        self.tree = self.make_branch_and_tree('.')
+        self.__create_and_add_test_file()
 
         # Modify the test file
         file('test_file', 'w').write(self.MODIFIED)
@@ -401,6 +388,4 @@
         # Unshelve, should succeed
         self.run_bzr('unshelve', '--all', retcode=0)
 
-        # Check the diff is right
-        self.assertEqual(self.capture('diff', retcode=1),
-            self.DIFF_HEADER + self.DIFF_1 + '\n')
+        self._check_diff()

